geochemistrypi package
======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   geochemistrypi.auth
   geochemistrypi.data_mining

Submodules
----------

geochemistrypi.cli module
-------------------------

.. automodule:: geochemistrypi.cli
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.database module
------------------------------

.. automodule:: geochemistrypi.database
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.start\_cli\_pipeline module
------------------------------------------

.. automodule:: geochemistrypi.start_cli_pipeline
   :members:
   :undoc-members:
   :show-inheritance:

geochemistrypi.start\_dash\_pipeline module
-------------------------------------------

.. automodule:: geochemistrypi.start_dash_pipeline
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: geochemistrypi
   :members:
   :undoc-members:
   :show-inheritance:
